@@ -1,5 +1,5 @@
 package ExtUtils::Builder::ParseXS;
-$ExtUtils::Builder::ParseXS::VERSION = '0.011';
+$ExtUtils::Builder::ParseXS::VERSION = '0.012';
 use strict;
 use warnings;
 
@@ -18,17 +18,20 @@ sub add_methods {
 
 		my @actions;
 		if ($options{mkdir}) {
+			my $dirname = dirname($destination);
 			push @actions, ExtUtils::Builder::Action::Function->new(
 				module    => 'File::Path',
 				function  => 'make_path',
-				arguments => [ dirname($destination) ],
+				arguments => [ $dirname ],
 				exports   => 'explicit',
+				message   => "mkdir $dirname",
 			);
 		}
 		push @actions, ExtUtils::Builder::Action::Function->new(
 			module    => 'ExtUtils::ParseXS',
 			function  => 'process_file',
 			arguments => [ filename => $source, prototypes => 0, output => $destination ],
+			message   => "parse-xs $source",
 		);
 
 		my @dependencies = @{ $options{dependencies} || [] };
@@ -84,7 +87,7 @@ ExtUtils::Builder::ParseXS - Essential functions for implementing XS in a Plan
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
